@@ -144,13 +144,16 @@ class lucia_start (dialogue.base):
 		"adonthell.gamedata_get_quest(\"demo\").get_val (\"soothe_lucia\") == 1 and adonthell.gamedata_get_quest(\"demo\").get_val (\"told_on_talan\") == 2\n"]
 
 	code = [\
+		"adonthell.achievements.update(2, 15)\n",\
 		"self.the_npc.set_val (\"talked_to\", 1)\n",\
 		"self.the_npc.set_val (\"know_shairs_clerk\", 1)\n",\
 		"adonthell.gamedata_get_quest(\"demo\").set_val (\"complain_about_wastesedge\" , 1)\n",\
 		"self.talked_about_fingolson = 1\nself.asked_about_noise = 1\nself.the_npc.set_val (\"talked_about_theft\", 1)\n",\
 		"self.asked_about_theft = 1\n",\
+		"adonthell.achievements.update(9, 18)\n",\
 		"self.talked_about_fingolson = 1\n",\
 		"self.asked_about_noise = 1\nself.the_npc.set_val (\"talked_about_theft\", 1) \n",\
+		"adonthell.achievements.update(9, 20)\n",\
 		"adonthell.gamedata_get_quest(\"demo\").set_val (\"know_talan_singing\" , 1)\n",\
 		"self.talked_about_fingolson = 1\nself.asked_about_noise = 1\n",\
 		"adonthell.gamedata_get_quest(\"demo\").set_val (\"pantry_locked\" , 2)\n",\
@@ -160,35 +163,35 @@ class lucia_start (dialogue.base):
 	# -- (speaker, code, ((text, operation, condition), ...))
 	dlg = [\
 		(None, -1, ((1, 0, 0), (92, 1, 8), (87, 1, -1), )),\
-		("Narrator", -1, ((2, 0, -1), )),\
+		("Narrator", 0, ((2, 0, -1), )),\
 		("Default", -1, ((3, 0, -1), (4, 0, -1), (6, 0, -1), )),\
-		(None, 0, ((8, 0, -1), )),\
-		(None, 0, ((5, 0, -1), )),\
+		(None, 1, ((8, 0, -1), )),\
+		(None, 1, ((5, 0, -1), )),\
 		("Default", -1, ((7, 0, -1), (50, 0, -1), )),\
 		(None, -1, ()),\
 		(None, -1, ((26, 0, -1), )),\
 		("Default", -1, ((9, 0, -1), (25, 0, -1), )),\
-		(None, 1, ((14, 0, -1), (10, 0, -1), )),\
+		(None, 2, ((14, 0, -1), (10, 0, -1), )),\
 		("Default", -1, ((12, 0, -1), (11, 0, -1), )),\
 		(None, -1, ((13, 0, -1), )),\
 		(None, -1, ((13, 0, -1), )),\
-		("Default", 2, ((30, 0, -1), (31, 0, -1), )),\
+		("Default", 3, ((30, 0, -1), (31, 0, -1), )),\
 		("Default", -1, ((15, 0, -1), )),\
-		("Default", 2, ((16, 0, -1), )),\
+		("Default", 3, ((16, 0, -1), )),\
 		(None, -1, ((17, 0, -1), )),\
-		("Default", 3, ((41, 0, -1), (18, 0, 1), )),\
+		("Default", 4, ((41, 0, -1), (18, 0, 1), )),\
 		("Default", -1, ((85, 0, 6), (68, 0, 3), (19, 0, -1), )),\
 		(None, -1, ((23, 0, -1), (21, 0, -1), )),\
 		(None, -1, ((23, 0, -1), )),\
-		("Default", 4, ((20, 0, -1), (22, 0, -1), (11, 0, -1), )),\
+		("Default", 5, ((20, 0, -1), (22, 0, -1), (11, 0, -1), )),\
 		(None, -1, ((24, 0, -1), )),\
 		("Default", -1, ((32, 0, -1), )),\
 		("Default", -1, ((59, 0, -1), )),\
-		(None, -1, ((26, 0, -1), )),\
+		(None, 6, ((26, 0, -1), )),\
 		("Default", -1, ((27, 0, -1), )),\
-		("Default", 5, ((28, 0, -1), (33, 0, -1), )),\
-		(None, 1, ((18, 0, 1), (29, 0, -1), (34, 0, -1), )),\
-		("Default", 2, ((30, 0, -1), (31, 0, -1), )),\
+		("Default", 7, ((28, 0, -1), (33, 0, -1), )),\
+		(None, 2, ((18, 0, 1), (29, 0, -1), (34, 0, -1), )),\
+		("Default", 3, ((30, 0, -1), (31, 0, -1), )),\
 		(None, -1, ((37, 0, -1), )),\
 		(None, -1, ((40, 0, -1), )),\
 		("Default", -1, ((100, 0, 11), (39, 0, -1), )),\
@@ -214,7 +217,7 @@ class lucia_start (dialogue.base):
 		("Default", -1, ((39, 0, -1), (28, 0, -1), )),\
 		("Default", -1, ((33, 0, -1), (54, 0, -1), )),\
 		(None, -1, ((55, 0, -1), )),\
-		("Default", 6, ((56, 0, -1), )),\
+		("Default", 8, ((56, 0, -1), )),\
 		("Default", -1, ((85, 0, 6), (68, 0, 3), (57, 0, -1), )),\
 		(None, -1, ((23, 0, -1), )),\
 		("Default", -1, ((64, 0, -1), )),\
@@ -233,8 +236,8 @@ class lucia_start (dialogue.base):
 		("Default", -1, ()),\
 		(None, -1, ((73, 0, 5), (77, 1, -1), )),\
 		("Default", -1, ((74, 0, -1), (78, 0, -1), )),\
-		(None, -1, ((75, 0, -1), )),\
-		("Default", 7, ((76, 0, -1), )),\
+		(None, 9, ((75, 0, -1), )),\
+		("Default", 10, ((76, 0, -1), )),\
 		(None, -1, ()),\
 		("Default", -1, ((81, 0, -1), )),\
 		(None, -1, ((79, 0, -1), )),\
@@ -250,7 +253,7 @@ class lucia_start (dialogue.base):
 		("Default", -1, ((104, 0, 12), (89, 0, 7), (98, 0, 9), )),\
 		(None, -1, ((90, 0, -1), )),\
 		("Default", -1, ((91, 0, -1), )),\
-		("Default", 8, ((41, 0, -1), (18, 0, 1), )),\
+		("Default", 11, ((41, 0, -1), (18, 0, 1), )),\
 		("Narrator", -1, ((117, 0, 13), (109, 1, 12), (93, 1, -1), )),\
 		(None, -1, ((94, 0, -1), )),\
 		("Default", -1, ((95, 0, -1), )),\
@@ -263,13 +266,13 @@ class lucia_start (dialogue.base):
 		("Default", -1, ((102, 0, -1), )),\
 		(None, -1, ((44, 0, -1), )),\
 		("Default", -1, ((63, 0, -1), )),\
-		(None, 9, ((105, 0, -1), )),\
+		(None, 12, ((105, 0, -1), )),\
 		("Default", -1, ((106, 0, -1), )),\
 		(None, -1, ((107, 0, -1), )),\
 		("Default", -1, ((108, 0, -1), )),\
 		("Narrator", -1, ()),\
 		(None, -1, ((110, 0, -1), )),\
-		("Default", 10, ((117, 0, 13), (95, 0, -1), (111, 0, -1), )),\
+		("Default", 13, ((117, 0, 13), (95, 0, -1), (111, 0, -1), )),\
 		(None, -1, ((112, 0, -1), )),\
 		("Default", -1, ((113, 0, -1), (115, 0, -1), )),\
 		(None, -1, ((114, 0, -1), )),\
@@ -278,7 +281,7 @@ class lucia_start (dialogue.base):
 		("Default", -1, ((97, 0, -1), )),\
 		(None, -1, ((118, 0, -1), )),\
 		("Default", -1, ((119, 0, -1), )),\
-		(None, 11, ((120, 0, -1), )),\
+		(None, 14, ((120, 0, -1), )),\
 		("Narrator", -1, ())]
 
 
