@@ -158,8 +158,9 @@ class orloth_start (dialogue.base):
 		"adonthell.gamedata_get_character(\"Lucia Redwyne\").get_val (\"refuses_key\") == 1\n"]
 
 	code = [\
-		"self.the_npc.set_val (\"talked_to\" , 1)\nself.first_run = 1\n",\
+		"self.the_npc.set_val (\"talked_to\" , 1)\nself.first_run = 1\nadonthell.achievements.update(2, 19)\n",\
 		"self.the_npc.set_val (\"told_about_shair\", 1)\nmyvar = adonthell.gamedata_get_quest(\"demo\").get_val (\"work_4_shair\")\nmyvar = myvar | 1\nadonthell.gamedata_get_quest(\"demo\").set_val (\"work_4_shair\" , myvar)\n",\
+		"adonthell.achievements.update(9, 22)\n",\
 		"self.introduce_guests = 1\n",\
 		"adonthell.gamedata_get_quest(\"demo\").set_val (\"know_aleks_room\" , 1)\n",\
 		"adonthell.gamedata_get_quest(\"demo\").set_val (\"know_erek\" , 1)\n",\
@@ -180,17 +181,17 @@ class orloth_start (dialogue.base):
 		("Default", -1, ((6, 0, -1), )),\
 		("Default", -1, ((7, 0, -1), (8, 0, -1), )),\
 		(None, 1, ((11, 0, -1), )),\
-		(None, -1, ((9, 0, -1), )),\
+		(None, 2, ((9, 0, -1), )),\
 		("Default", -1, ((86, 0, -1), )),\
-		("Default", 2, ((117, 0, -1), )),\
+		("Default", 3, ((117, 0, -1), )),\
 		("Default", -1, ((83, 0, -1), )),\
 		(None, -1, ((13, 0, -1), )),\
 		("Default", -1, ((89, 0, -1), (90, 0, -1), (91, 0, -1), )),\
 		("Default", -1, ((15, 0, -1), )),\
-		("Default", 3, ((17, 0, -1), (16, 0, -1), )),\
+		("Default", 4, ((17, 0, -1), (16, 0, -1), )),\
 		(None, -1, ((18, 0, -1), )),\
 		(None, -1, ((48, 0, -1), )),\
-		("Default", 4, ((27, 0, -1), )),\
+		("Default", 5, ((27, 0, -1), )),\
 		("Default", -1, ((20, 0, -1), )),\
 		("Default", -1, ((17, 0, -1), (21, 0, -1), )),\
 		(None, -1, ((22, 0, -1), )),\
@@ -198,17 +199,17 @@ class orloth_start (dialogue.base):
 		("Default", -1, ((24, 0, -1), )),\
 		("Default", -1, ((89, 0, -1), (116, 0, 10), (44, 0, 6), )),\
 		(None, -1, ((104, 0, -1), )),\
-		("Default", 5, ((25, 0, -1), )),\
+		("Default", 6, ((25, 0, -1), )),\
 		("Default", -1, ((17, 0, -1), (114, 0, 9), (115, 0, -1), )),\
 		("Default", -1, ((105, 0, -1), (103, 0, -1), )),\
 		("Default", -1, ((30, 0, -1), )),\
 		("Default", -1, ((109, 0, -1), )),\
 		(None, -1, ((35, 0, 2), )),\
 		("Default", -1, ((119, 0, 11), (41, 1, 4), (82, 1, -1), )),\
-		(None, 6, ((36, 0, -1), )),\
+		(None, 7, ((36, 0, -1), )),\
 		(None, -1, ((36, 0, -1), )),\
 		("Default", -1, ((33, 0, 1), (34, 0, -1), )),\
-		("Default", 7, ((37, 0, 3), (111, 1, -1), )),\
+		("Default", 8, ((37, 0, 3), (111, 1, -1), )),\
 		("Narrator", -1, ()),\
 		("Default", -1, ((39, 0, -1), )),\
 		("Default", -1, ((74, 0, -1), )),\
@@ -264,12 +265,12 @@ class orloth_start (dialogue.base):
 		(None, -1, ((35, 0, 2), )),\
 		(None, -1, ((92, 0, -1), )),\
 		(None, -1, ((10, 0, -1), )),\
-		("Default", 8, ((93, 0, -1), (94, 0, -1), )),\
+		("Default", 9, ((93, 0, -1), (94, 0, -1), )),\
 		(None, -1, ((96, 0, -1), )),\
 		(None, -1, ((95, 0, -1), )),\
 		("Default", -1, ((96, 0, -1), )),\
 		("Default", -1, ((97, 0, -1), )),\
-		("Default", 9, ((98, 0, -1), )),\
+		("Default", 10, ((98, 0, -1), )),\
 		("Default", -1, ((99, 0, -1), )),\
 		(None, -1, ((100, 0, -1), )),\
 		("Default", -1, ((101, 0, -1), (102, 0, -1), (103, 0, -1), )),\
@@ -286,7 +287,7 @@ class orloth_start (dialogue.base):
 		("Narrator", -1, ()),\
 		(None, -1, ((35, 0, 2), )),\
 		(None, -1, ((10, 0, -1), )),\
-		(None, 5, ((19, 0, -1), )),\
+		(None, 6, ((19, 0, -1), )),\
 		(None, -1, ((22, 0, -1), )),\
 		(None, -1, ((92, 0, -1), )),\
 		("Default", -1, ((14, 0, -1), )),\
@@ -301,9 +302,9 @@ class orloth_start (dialogue.base):
 		(None, -1, ((132, 0, -1), )),\
 		(None, -1, ((128, 0, -1), )),\
 		("Default", -1, ((131, 0, -1), (129, 0, -1), )),\
-		(None, 10, ((130, 0, -1), )),\
+		(None, 11, ((130, 0, -1), )),\
 		("Default", -1, ((134, 0, -1), )),\
-		(None, 10, ((133, 0, -1), )),\
+		(None, 11, ((133, 0, -1), )),\
 		("Default", -1, ((131, 0, -1), (129, 0, -1), )),\
 		("Default", -1, ()),\
 		("Default", -1, ())]
